@@ -73,5 +73,9 @@ test_that("Check get_ts works with other types", {
                structure(c(1L, 10L), .Dim = 2L,
                          .Dimnames = structure(list(c("0", "1")), .Names = ""),
                          class = "table"))
-
+  x3 <- get_ts(id = 72014, type = "pot-flow", full_info = TRUE)
+  expect_equal(table(x3$rejected[1:176]),
+               structure(c(`0` = 176L), .Dim = 1L, 
+                         .Dimnames = structure(list("0"), .Names = ""), 
+                         class = "table"))
 })
